CREATE DATABASE TSHIRTS;

GRANT ALL PRIVILEGES ON TSHIRTS.* TO TSHIRTS@localhost IDENTIFIED BY 'TSHIRTS' WITH GRANT OPTION;
GRANT ALL PRIVILEGES ON TSHIRTS.* TO TSHIRTS@"%" IDENTIFIED BY 'TSHIRTS' WITH GRANT OPTION;

-- CREATE TABLE CUSTOMER
CREATE TABLE TSHIRTS.CUSTOMER
(
	CUSTOMER_ID INTEGER NOT NULL, 
	FIRST_NAME VARCHAR(30) NOT NULL, 
	LAST_NAME VARCHAR(30) NOT NULL, 
	MIDDLE_NAME VARCHAR(20) NOT NULL, 
	ADDRESS_1 VARCHAR(50) NOT NULL, 
	ADDRESS_2 VARCHAR(50) , 
	CITY VARCHAR(50) NOT NULL, 
	STATE CHAR(2) NOT NULL, 
	ZIP_CODE VARCHAR(5), 
	PHONE VARCHAR(12), 
	EMAIL VARCHAR(50) NOT NULL UNIQUE,
	PRIMARY KEY(CUSTOMER_ID)
 );

-- create table STATE
CREATE TABLE TSHIRTS.STATE
      (
	CODE CHAR(2) NOT NULL, 
	STATE_NAME VARCHAR(50) NOT NULL
      ) ; 

-- create table ORDERS
CREATE TABLE TSHIRTS.ORDERS(
	ORDER_ID INTEGER NOT NULL, 
	CUSTOMER_ID_FK INTEGER NOT NULL, 
	ORDER_DATE DATE, 
	SHIP_INSTRUCT VARCHAR(100), 
	SHIP_DATE DATE, 
	SHIP_WEIGHT FLOAT,
	SHIP_CHARGE FLOAT, 
	PAID_DATE DATE,
	PRIMARY KEY(ORDER_ID),
	FOREIGN KEY(CUSTOMER_ID_FK) REFERENCES TSHIRTS.CUSTOMER(CUSTOMER_ID)
     );
-- create table ITEM
CREATE TABLE TSHIRTS.ITEM(
	ITEM_ID INTEGER NOT NULL,
	ORDER_ID_FK INTEGER NOT NULL,
	 QUANTITY INTEGER,
	TOTAL_PRICE FLOAT,
	PRIMARY KEY(ITEM_ID),
	FOREIGN KEY(ORDER_ID_FK) REFERENCES TSHIRTS.ORDERS(ORDER_ID)
       );
-- create table SUPPLIER
CREATE TABLE TSHIRTS.SUPPLIER(
	SUPPLIER_ID INTEGER NOT NULL,
  NAME        VARCHAR(30) ,
  ADDRESS_1   VARCHAR(30) ,
  ADDRESS_2   VARCHAR(30) ,
  CITY        VARCHAR(40) ,
  STATE       VARCHAR(2)  ,
  ZIP         VARCHAR(5)  ,
  PRIMARY KEY(SUPPLIER_ID)
  );
-- CREATE TABLE TSHIRT
CREATE TABLE TSHIRTS.TSHIRT
	(ITEM_ID_FK INTEGER, 
	SHIRT_ID INTEGER NOT NULL, 
	SHIRT_SIZE VARCHAR(5),
	UNIT_PRICE FLOAT, 
	COLOR VARCHAR(10), 
	DESIGN_FRONT VARCHAR(10), 
	DESIGN_BACK VARCHAR(10), 
	PICTURE_FRONT VARCHAR(50), -- this type is not in Cloud Scape
	PICTURE_BACK VARCHAR(50), -- this type is not in Cloud Scape
  SUPPLIER_ID_FK INTEGER,
-- Unit price need to enter here.
	 FOREIGN KEY(ITEM_ID_FK) REFERENCES TSHIRTS.ITEM(ITEM_ID),
   FOREIGN KEY(SUPPLIER_ID_FK) REFERENCES TSHIRTS.SUPPLIER(SUPPLIER_ID),
	 PRIMARY KEY(SHIRT_ID)
	);

-- create type CARD_TYPE
CREATE TABLE TSHIRTS.CHARGE_CARD_TYPE ( 
	CARD_TYPE VARCHAR(6) NOT NULL,
	CARD_NAME VARCHAR(8) NOT NULL,
	CARD_NUMBER VARCHAR(20) NOT NULL,
	EXPIRE_DATE DATE NOT NULL ,
	CARD_CONFIRMATION_NUMBER VARCHAR(20),
        PRIMARY KEY(CARD_NUMBER)
	);
-- CREATE TABLE CREDIT
CREATE TABLE TSHIRTS.CREDIT(
	CUSTOMER_ID_FK INTEGER NOT NULL,
	ORDER_ID_FK INTEGER  NOT NULL,
	CARD_NUMBER_FK VARCHAR(20) NOT NULL ,
	FOREIGN KEY(CUSTOMER_ID_FK) REFERENCES TSHIRTS.CUSTOMER(CUSTOMER_ID),
	FOREIGN KEY(ORDER_ID_FK) REFERENCES TSHIRTS.ORDERS(ORDER_ID),
	FOREIGN KEY(CARD_NUMBER_FK) REFERENCES TSHIRTS.CHARGE_CARD_TYPE(CARD_NUMBER)
	);

-- CREATE TABLE Address
CREATE TABLE TSHIRTS.ADDRESS(
    ORDER_ID_FK INTEGER NOT NULL,
    ADDRESS_TYPE VARCHAR(20),
    ADDRESS_1    VARCHAR(40),
    ADDRESS_2    VARCHAR(40),
    CITY         VARCHAR(50),
    STATE        CHAR(2),
    ZIP_CODE     CHAR(5),
    FOREIGN KEY(ORDER_ID_FK) REFERENCES TSHIRTS.ORDERS(ORDER_ID)
    );

-- CREATE TABLE AUTHENTICATION

CREATE TABLE TSHIRTS.AUTHENTICATION(
   AUTH_ID INTEGER NOT NULL,
   CUSTOMER_ID_FK INTEGER ,
   PASSWORD  VARCHAR(20)  NOT NULL,
   AUTH_TYPE VARCHAR(20) NOT NULL ,
   ACTIVE    VARCHAR(20) NOT NULL,
   FOREIGN KEY(CUSTOMER_ID_FK) REFERENCES TSHIRTS.CUSTOMER(CUSTOMER_ID),
   PRIMARY KEY(AUTH_ID)
   );

-- Load data into CUSTOMER table
INSERT INTO TSHIRTS.CUSTOMER VALUES( '101','Rajiv','Pauli','','213 Erstwild Court','Apt 30','Sunnyvale','CA','94086','408-789-8075','rp@rpuli.com');
INSERT INTO TSHIRTS.CUSTOMER VALUES( '102','Carole','Sandler','S','785 Geary St','','San Francisco','CA','94117','415-822-1289','cs@sandler.com');
INSERT INTO TSHIRTS.CUSTOMER VALUES( '103','Philip','Currie','','654 Poplar','Apt 50','Wahsington','CA','94303','415-328-4543','pc@pCurrie.com');
INSERT INTO TSHIRTS.CUSTOMER VALUES( '104','Tony','Higgins','H','East Shopping Cntr.','422 Bay Road','Altanta','GA','94026','415-368-1100','th@tHiggins.com');
INSERT INTO TSHIRTS.CUSTOMER VALUES( '105', 'Rio','Vector','','1899 La Loma Drive','','Los Altos','CA','94022','415-776-3249','rv@rvictor.com');
INSERT INTO TSHIRTS.CUSTOMER VALUES( '106','Erick','Watson','','1143 Carver Place','','Mountain View','CA','94063','415-389-8789','ew@ewaston.com');
INSERT INTO TSHIRTS.CUSTOMER VALUES( '107','Charles','Ream','','41 Jordan Avenue','','Palo Alto','CA','94304','415-356-9876','cr@cReam.com');
INSERT INTO TSHIRTS.CUSTOMER VALUES( '108','Donald','Duck','','587 Alvarado','','Redwood City','CA','94063','415-544-8729','dd@dDuck.com');
INSERT INTO TSHIRTS.CUSTOMER VALUES( '109','Ray','Miller','','Mayfair Mart','7345 Ross Blvd.','San Diego','CA','94086','408-723-8789','rm@rmiller.com');
INSERT INTO TSHIRTS.CUSTOMER VALUES( '110','Ray','Jaguar','F','520 Topaz Way','','Redwood City','CA','94062','415-743-3611','rj@rjaguar.com');
INSERT INTO TSHIRTS.CUSTOMER VALUES( '111','Francis','Keyes','','3199 Sterling Court','','Sunnyvale','CA','94085','408-277-7245','fk@fKeyes.com');
INSERT INTO TSHIRTS.CUSTOMER VALUES( '112','Margaret','Rosenthal','','234 Wyandotte Way','','Los Altos','CA','94022','415-887-7235','mr@mRosenthal.com');
INSERT INTO TSHIRTS.CUSTOMER VALUES( '113','Betty','Beatty','','654 Oak Grove','','Menlo Park','CA','94025','415-356-9982','bb@bbeatty.com');
INSERT INTO TSHIRTS.CUSTOMER VALUES( '114','Frank','Albertson','','947 Waverly Place','','Cleveland','OH','94062','415-886-6677','fa@Albertson.com');
INSERT INTO TSHIRTS.CUSTOMER VALUES( '115','Alfred','Greenspan','G','776 Gary Avenue','','Denver','CO','94025','415-356-1123','ag@agreenspan.com');
INSERT INTO TSHIRTS.CUSTOMER VALUES( '116','Ariana','Parmelee','','1104 Spinosa Drive','','Mountain View','CA','94040','415-534-8822','ap@Parmelee.com');
INSERT INTO TSHIRTS.CUSTOMER VALUES( '117','Arnold','Ken','','850 Lytton Court','','Dulles','VA','94063','415-245-4578','ak@aKen.com');
INSERT INTO TSHIRTS.CUSTOMER VALUES( '118','Richard','Baxter','','5427 College','','Oakland','CA','94609','415-655-0011','rb@rBaxter.com');
INSERT INTO TSHIRTS.CUSTOMER VALUES( '119','Bob','Shorter','','2405 Kings Highway','','Cherry Hill','NJ','08002','609-663-6079','rw@rShorter.com');
INSERT INTO TSHIRTS.CUSTOMER VALUES( '120','Robert','Willcock','','6627 N. 17th Way','','Milwaukee','WI','85016','602-265-8754','rw@rWillcock.com');
INSERT INTO TSHIRTS.CUSTOMER VALUES( '121','Jay','Wallack','','Lake Biltmore Mall','','Newark','DE','19898','302-366-7511','jw@jwallack.com');
INSERT INTO TSHIRTS.CUSTOMER VALUES( '122','Catherine','Jones','','543 Nassau Street','','Princeton','NJ','08540','609-342-0054','cb@cbrian.com');
INSERT INTO TSHIRTS.CUSTOMER VALUES( '123','Mario','Hanion','','10100 Bay Meadows Ro','Suite 120','Jacksonville','FL','32256','904-823-4239','mh@mHanion.com');
INSERT INTO TSHIRTS.CUSTOMER VALUES( '124','Chris','Patania','D','4715 S.E. Adams Blvd','Apt T1','Bartlesville','OK','74006','918-355-2074','cp@cpatania.com');
INSERT INTO TSHIRTS.CUSTOMER VALUES( '125','Johney','Henry','','1450 Commonwealth Av','','Brighton','MA','02135','617-232-4159','jh@jHenry.com');
INSERT INTO TSHIRTS.CUSTOMER VALUES( '126','Eleen','Neelie','','2539 South Utica Str','','Denver','CO','80219','303-936-7731','en@eNeelie.com');
INSERT INTO TSHIRTS.CUSTOMER VALUES( '127','Kid','Satifer','','Blue Island Square','','Hampton','VA','60406','312-944-5691','ks@kSatifer.com');
INSERT INTO TSHIRTS.CUSTOMER VALUES( '128','Frank','Little','','Athletic Department','','Baltimore','MD','85008','602-533-1817','fk@fLittle.com');
-- Load data into ORDERS table
INSERT INTO TSHIRTS.ORDERS VALUES( '1001' , '101' , '2002-02-02' , 'express' , '2002-02-03' , '20.4' , '10' , '2002-02-05' );
INSERT INTO TSHIRTS.ORDERS VALUES( '1002' , '102' , '2002-05-02' , 'PO on box; back door only' , '2002-05-04' , '50.6' , '15.3', '2002-05-12' );
INSERT INTO TSHIRTS.ORDERS VALUES( '1003' , '103' , '2002-10-11' , 'express' , '2002-10-12' , '35.6' , '10.8' , '2002-11-03'  );
INSERT INTO TSHIRTS.ORDERS VALUES( '1004' , '104' , '2002-02-10' , 'ring bell twice' , '2002-02-11' , '95.8' , '19.2' , '2002-02-12'  );
INSERT INTO TSHIRTS.ORDERS VALUES( '1005' , '105' , '2002-10-03' , 'call before delivery' , '2002-10-10' , '80.8' , '16.2' , '2002-10-12'  );
INSERT INTO TSHIRTS.ORDERS VALUES( '1006' , '106' , '2002-02-02' , 'express' , '2002-02-04' , '20.4' , '10' , '2002-02-08' );
INSERT INTO TSHIRTS.ORDERS VALUES( '1007' , '107' , '2002-05-02' , 'PO on box; back door only' , '2002-05-02' , '50.6' , '15.3' , '2002-05-04'  );
INSERT INTO TSHIRTS.ORDERS VALUES( '1008' , '108' , '2002-10-11' , 'express' , '2002-10-22' , '35.6' , '10.8' , '2002-10-23'  );
INSERT INTO TSHIRTS.ORDERS VALUES( '1009' , '109' , '2002-02-10' , 'ring bell twice' , '2002-02-11' , '95.8' , '19.2' , '2002-02-12'  );
INSERT INTO TSHIRTS.ORDERS VALUES( '1010' , '110' , '2002-08-03' , 'call before delivery' , '2002-08-10' , '80.8' , '16.2' , '2002-08-12' );
INSERT INTO TSHIRTS.ORDERS VALUES( '1011' , '111' , '2002-04-03' , 'express' , '2002-04-04' , '10.4' , '5' , '2002-04-13' );
INSERT INTO TSHIRTS.ORDERS VALUES( '1012' , '112' , '2002-07-12' , 'express' , '2002-07-13' , '20.4' , '10' , '2002-07-19' );
INSERT INTO TSHIRTS.ORDERS VALUES( '1013' , '113' , '2002-05-02' , 'PO on box; back door only' , '2002-05-03' , '50.6' , '15.3' , '2002-05-04'  );
INSERT INTO TSHIRTS.ORDERS VALUES( '1014' , '114' , '2002-10-01' , 'express' , '2002-10-02' , '35.6' , '10.8' , '2002-10-03' );
INSERT INTO TSHIRTS.ORDERS VALUES( '1015' , '115' , '2002-02-10' , 'ring bell twice' , '2002-02-11' , '95.8' , '19.2' , '2002-02-12'  );
INSERT INTO TSHIRTS.ORDERS VALUES( '1016' , '116' , '2002-09-03' , 'call before delivery' , '2002-09-10' , '80.8' , '16.2' , '2002-09-21'  );
INSERT INTO TSHIRTS.ORDERS VALUES( '1017' , '117' , '2002-01-02' , 'express' , '2002-01-06' , '60.8' , '12.2' , '2002-01-12'  );
INSERT INTO TSHIRTS.ORDERS VALUES( '1018' , '125' , '2002-06-13' , 'call before delivery' , '2002-06-18' , '180.8' , '16.2' , '2002-06-20'  );
INSERT INTO TSHIRTS.ORDERS VALUES( '1019' , '127' , '2002-03-02' , 'express' , '2002-03-09' , '160.8' , '12.2' , '2002-03-22'  );
-- Load data into STATE
INSERT INTO TSHIRTS.STATE VALUES ( 'AK' , 'Alaska');
INSERT INTO TSHIRTS.STATE VALUES ( 'HI' , 'Hawaii');
INSERT INTO TSHIRTS.STATE VALUES ( 'CA' , 'California');
INSERT INTO TSHIRTS.STATE VALUES ( 'OR' , 'Oregon');
INSERT INTO TSHIRTS.STATE VALUES ( 'WA' , 'Washington');
INSERT INTO TSHIRTS.STATE VALUES ( 'ID' , 'Idaho');
INSERT INTO TSHIRTS.STATE VALUES ( 'NV' , 'Nevada');
INSERT INTO TSHIRTS.STATE VALUES ( 'MT' , 'Montana');
INSERT INTO TSHIRTS.STATE VALUES ( 'WY' , 'Wyoming');
INSERT INTO TSHIRTS.STATE VALUES ( 'UT' , 'Utah');
INSERT INTO TSHIRTS.STATE VALUES ( 'AZ' , 'Arizona');
INSERT INTO TSHIRTS.STATE VALUES ( 'NM' , 'New Mexico');
INSERT INTO TSHIRTS.STATE VALUES ( 'CO' , 'Colorado');
INSERT INTO TSHIRTS.STATE VALUES ( 'ND' , 'North Dakota');
INSERT INTO TSHIRTS.STATE VALUES ( 'SD' , 'South Dakota');
INSERT INTO TSHIRTS.STATE VALUES ( 'NE' , 'Nebraska');
INSERT INTO TSHIRTS.STATE VALUES ( 'KS' , 'Kansas');
INSERT INTO TSHIRTS.STATE VALUES ( 'OK' , 'Oklahoma');
INSERT INTO TSHIRTS.STATE VALUES ( 'TX' , 'Texas');
INSERT INTO TSHIRTS.STATE VALUES ( 'MN' , 'Minnesota');
INSERT INTO TSHIRTS.STATE VALUES ( 'IA' , 'Iowa');
INSERT INTO TSHIRTS.STATE VALUES ( 'MO' , 'Missouri');
INSERT INTO TSHIRTS.STATE VALUES ( 'AR' , 'Arkansas');
INSERT INTO TSHIRTS.STATE VALUES ( 'LA' , 'Louisiana');
INSERT INTO TSHIRTS.STATE VALUES ( 'WI' , 'Wisconsin');
INSERT INTO TSHIRTS.STATE VALUES ( 'IL' , 'Illinois');
INSERT INTO TSHIRTS.STATE VALUES ( 'MS' , 'Mississippi');
INSERT INTO TSHIRTS.STATE VALUES ( 'AL' , 'Alabama');
INSERT INTO TSHIRTS.STATE VALUES ( 'FL' , 'Florida');
INSERT INTO TSHIRTS.STATE VALUES ( 'GA' , 'Georgia');
INSERT INTO TSHIRTS.STATE VALUES ( 'SC' , 'South Carolina');
INSERT INTO TSHIRTS.STATE VALUES ( 'NC' , 'North Carolina');
INSERT INTO TSHIRTS.STATE VALUES ( 'TN' , 'Tennessee');
INSERT INTO TSHIRTS.STATE VALUES ( 'KY' , 'Kentucky');
INSERT INTO TSHIRTS.STATE VALUES ( 'VA' , 'Virginia');
INSERT INTO TSHIRTS.STATE VALUES ( 'WV' , 'West Virginia');
INSERT INTO TSHIRTS.STATE VALUES ( 'MD' , 'Maryland');
INSERT INTO TSHIRTS.STATE VALUES ( 'IN' , 'Indiana');
INSERT INTO TSHIRTS.STATE VALUES ( 'MI' , 'Michigan');
INSERT INTO TSHIRTS.STATE VALUES ( 'OH' , 'Ohio');
INSERT INTO TSHIRTS.STATE VALUES ( 'PA' , 'Pennsylvania');
INSERT INTO TSHIRTS.STATE VALUES ( 'DE' , 'Delaware');
INSERT INTO TSHIRTS.STATE VALUES ( 'NJ' , 'New Jersey');
INSERT INTO TSHIRTS.STATE VALUES ( 'NY' , 'New York');
INSERT INTO TSHIRTS.STATE VALUES ( 'CT' , 'Connecticut');
INSERT INTO TSHIRTS.STATE VALUES ( 'VT' , 'Vermont');
INSERT INTO TSHIRTS.STATE VALUES ( 'RI' , 'Rhode Island');
INSERT INTO TSHIRTS.STATE VALUES ( 'MA' , 'Massachusetts');
INSERT INTO TSHIRTS.STATE VALUES ( 'NH' , 'New Hampshire');
INSERT INTO TSHIRTS.STATE VALUES ( 'ME' , 'Maine');
INSERT INTO TSHIRTS.STATE VALUES ( 'DC' , 'District of Columbia'); 
INSERT INTO TSHIRTS.STATE VALUES ( 'PR' , 'Puerto Rico');
-- Insert data into ITEM table
INSERT INTO TSHIRTS.ITEM VALUES('1' , '1001' , '10' , '240.00' );
INSERT INTO TSHIRTS.ITEM VALUES('2' , '1002' , '10' , '800.00' );
INSERT INTO TSHIRTS.ITEM VALUES('3' , '1003' , '10' , '48.00' ); 
INSERT INTO TSHIRTS.ITEM VALUES('4' , '1004' , '10' , '36.00' ); 
INSERT INTO TSHIRTS.ITEM VALUES('5' , '1005' , '10' , '48.00' ); 
INSERT INTO TSHIRTS.ITEM VALUES('6' , '1006' , '10' , '480.00' ); 
INSERT INTO TSHIRTS.ITEM VALUES('7' , '1007' , '1' , '600.00' ); 
INSERT INTO TSHIRTS.ITEM VALUES('8' , '1008' , '20' , '40.00' ); 
INSERT INTO TSHIRTS.ITEM VALUES('9' , '1009' , '10' , '120.00' ); 
INSERT INTO TSHIRTS.ITEM VALUES('10' , '1010' , '20' , '204.00' ); 
INSERT INTO TSHIRTS.ITEM VALUES('11' , '1011' , '40' , '100.00' ); 
INSERT INTO TSHIRTS.ITEM VALUES('12' , '1012' , '10' , '280.00' ); 
INSERT INTO TSHIRTS.ITEM VALUES('13' , '1013' , '30' ,  '1499.97' ); 
INSERT INTO TSHIRTS.ITEM VALUES('14' , '1014' , '20' , '624.00' ); 
INSERT INTO TSHIRTS.ITEM VALUES('15' , '1015' , '10' , '228.00' ); 
INSERT INTO TSHIRTS.ITEM VALUES('16' , '1016' , '10' , '170.00' );
INSERT INTO TSHIRTS.ITEM VALUES('76' , '1017' , '10' , '190.00' );
INSERT INTO TSHIRTS.ITEM VALUES('77' , '1018' , '10' , '160.00' );
INSERT INTO TSHIRTS.ITEM VALUES('78' , '1019' , '10' , '190.00' );
-- Insert data into SUPPLIER Table
insert into TSHIRTS.SUPPLIER values('1','PureShirts','120 Lance St.','Suite 500','Lakeville','KY','13556');
insert into TSHIRTS.SUPPLIER values('2','XMLShirts','Jini Ct.','500','Talladega','AL','12345');
-- Insert data into TSHIRT table
insert into TSHIRTS.TSHIRT values('1','10','XL','10.5','White','123','135','shirtOne.jpg','shirtOne.jpg','1');
insert into TSHIRTS.TSHIRT values('2','11','XL','7.5','Green','123','135','shirtTwo.jpg','shirtTwo.jpg','2');
insert into TSHIRTS.TSHIRT values('3','12','XL','5.5','Green','123','135','shirtThree.jpg','shirtThree.jpg','1');
insert into TSHIRTS.TSHIRT values('4','13','XL','10.5','White','123','135','shirtFour.jpg','shirtFour.jpg','1');
insert into TSHIRTS.TSHIRT values('5','14','L','10.5','White','123','135','shirtFive.jpg','shirtOFive.jpg','1');
insert into TSHIRTS.TSHIRT values('6','15','L','6.5','Black','123','135','shirtSix.jpg','shirtSix.jpg','1');
insert into TSHIRTS.TSHIRT values('7','16','L','10.5','White','123','135','shirtSeven.jpg','shirtSeven.jpg','2');
insert into TSHIRTS.TSHIRT values('8','17','L','7.5','Green','123','135','shirtEight.jpg','shirtEight.jpg','2');
insert into TSHIRTS.TSHIRT values('9','18','L','10.5','White','123','135','shirtOne.jpg','shirtOne.jpg','1');
insert into TSHIRTS.TSHIRT values('10','19','L','6.5','White','123','135','shirtTwo.jpg','shirtTwo.jpg','2');
insert into TSHIRTS.TSHIRT values('11','20','L','10.5','Green','123','135','shirtThree.jpg','shirtThree.jpg','1');
insert into TSHIRTS.TSHIRT values('12','21','M','5.5','White','123','135','shirtFour.jpg','shirtFour.jpg','2');
insert into TSHIRTS.TSHIRT values('13','22','M','10.5','White','123','135','shirtFive.jpg','shirtOFive.jpg','1');
insert into TSHIRTS.TSHIRT values('14','23','M','6.5','Green','123','135','shirtSix.jpg','shirtSix.jpg','1');
insert into TSHIRTS.TSHIRT values('15','24','M','10.5','Black','123','135','shirtSeven.jpg','shirtSeven.jpg','1');
insert into TSHIRTS.TSHIRT values('16','25','M','7.5','White','123','135','shirtEight.jpg','shirtEight.jpg','2');
insert into TSHIRTS.TSHIRT values('1','26','S','1.5','Green','123','135','shirtOne.jpg','shirtOne.jpg','2');
insert into TSHIRTS.TSHIRT values('2','27','S','10.5','White','123','135','shirtFour.jpg','shirtFour.jpg','1');
insert into TSHIRTS.TSHIRT values('3','28','S','7.5','Black','123','135','shirtSeven.jpg','shirtSeven.jpg','1');
insert into TSHIRTS.TSHIRT values('4','29','S','5.5','White','123','135','shirtTwo.jpg','shirtTwo.jpg','1');
insert into TSHIRTS.TSHIRT values('5','30','S','3.5','Green','123','135','shirtTwo.jpg','shirtTwo.jpg','2');
insert into TSHIRTS.TSHIRT values('6','31','S','6.5','White','123','135','shirtFour.jpg','shirtFour.jpg','1');
insert into TSHIRTS.TSHIRT values('7','32','S','1.5','Black','123','135','shirtFour.jpg','shirtFour.jpg','2');
insert into TSHIRTS.TSHIRT values('8','33','S','6.5','Green','123','135','shirtFour.jpg','shirtFour.jpg','1');

-- insert data into AUTHENTICATION table
INSERT INTO TSHIRTS.AUTHENTICATION VALUES('1', '101','rajiv','PASSWORD', 'TRUE');
INSERT INTO TSHIRTS.AUTHENTICATION VALUES('2', '102','carole','PASSWORD', 'TRUE');
INSERT INTO TSHIRTS.AUTHENTICATION VALUES('3', '103','philip','PASSWORD', 'TRUE');
INSERT INTO TSHIRTS.AUTHENTICATION VALUES('4', '104','tony','PASSWORD', 'TRUE');
INSERT INTO TSHIRTS.AUTHENTICATION VALUES('5', '105','tio', 'PASSWORD', 'TRUE');
INSERT INTO TSHIRTS.AUTHENTICATION VALUES('6', '106','erick','PASSWORD', 'TRUE');
INSERT INTO TSHIRTS.AUTHENTICATION VALUES('7', '107','charles','PASSWORD', 'TRUE');
INSERT INTO TSHIRTS.AUTHENTICATION VALUES('8', '108','donald','PASSWORD', 'TRUE');
INSERT INTO TSHIRTS.AUTHENTICATION VALUES('9', '109','ray','PASSWORD', 'TRUE');
INSERT INTO TSHIRTS.AUTHENTICATION VALUES('10', '110','ray1','PASSWORD', 'TRUE');
INSERT INTO TSHIRTS.AUTHENTICATION VALUES('11', '111','francis','PASSWORD', 'TRUE');
INSERT INTO TSHIRTS.AUTHENTICATION VALUES('12', '112','margarate','PASSWORD', 'TRUE');
INSERT INTO TSHIRTS.AUTHENTICATION VALUES('13', '113','betty','PASSWORD', 'TRUE');
INSERT INTO TSHIRTS.AUTHENTICATION VALUES('14', '114','frank','PASSWORD', 'TRUE');
INSERT INTO TSHIRTS.AUTHENTICATION VALUES('15', '115','alfred','PASSWORD', 'TRUE');
INSERT INTO TSHIRTS.AUTHENTICATION VALUES('16', '116','ariana','PASSWORD', 'TRUE');
INSERT INTO TSHIRTS.AUTHENTICATION VALUES('17', '117','arnold','PASSWORD', 'TRUE');
INSERT INTO TSHIRTS.AUTHENTICATION VALUES('18', '118','ridhard','PASSWORD', 'TRUE');
INSERT INTO TSHIRTS.AUTHENTICATION VALUES('19', '119','bob','PASSWORD', 'TRUE');
INSERT INTO TSHIRTS.AUTHENTICATION VALUES('20', '120','robert','PASSWORD', 'TRUE');
INSERT INTO TSHIRTS.AUTHENTICATION VALUES('21', '121','jay','PASSWORD', 'TRUE');
INSERT INTO TSHIRTS.AUTHENTICATION VALUES('22', '122','catherine','PASSWORD', 'TRUE');
INSERT INTO TSHIRTS.AUTHENTICATION VALUES('23', '123','mario','PASSWORD', 'TRUE');
INSERT INTO TSHIRTS.AUTHENTICATION VALUES('24', '124','chris','PASSWORD', 'TRUE');
INSERT INTO TSHIRTS.AUTHENTICATION VALUES('25', '125','johney','PASSWORD', 'TRUE');
INSERT INTO TSHIRTS.AUTHENTICATION VALUES('26', '126','eleen','PASSWORD', 'TRUE');
INSERT INTO TSHIRTS.AUTHENTICATION VALUES('27', '127','kid','PASSWORD', 'TRUE');
INSERT INTO TSHIRTS.AUTHENTICATION VALUES('28', '128','frank','PASSWORD', 'TRUE');

-- Load Data into CHARGE_CARD_TYPE   table
INSERT INTO TSHIRTS.CHARGE_CARD_TYPE VALUES ( 'CREDIT', 'VISA','123445656','2004-02-22','0123456789012'  );
INSERT INTO TSHIRTS.CHARGE_CARD_TYPE VALUES ( 'DEBIS', 'ATM','123455656','2004-02-22','1123456789012'  );
INSERT INTO TSHIRTS.CHARGE_CARD_TYPE VALUES ( 'CREDIT', 'MC','123465656','2004-02-22','2123456789012'  );
INSERT INTO TSHIRTS.CHARGE_CARD_TYPE VALUES ( 'CREDIT', 'VISA','123745656','2004-02-22','3123456789012'  );
INSERT INTO TSHIRTS.CHARGE_CARD_TYPE VALUES ( 'CREDIT', 'VISA','123855656','2004-02-22','3123456789012'  );
INSERT INTO TSHIRTS.CHARGE_CARD_TYPE VALUES ( 'CREDIT', 'VISA','123965656','2004-02-22','3123456789012'  );

-- Load Data into CREDIT table
INSERT INTO TSHIRTS.CREDIT VALUES ('101', '1001', '123445656');
INSERT INTO TSHIRTS.CREDIT VALUES ('101', '1002', '123455656');
INSERT INTO TSHIRTS.CREDIT VALUES ('101', '1003', '123465656');
INSERT INTO TSHIRTS.CREDIT VALUES ('105', '1001', '123745656');
INSERT INTO TSHIRTS.CREDIT VALUES ('105', '1002', '123855656');
INSERT INTO TSHIRTS.CREDIT VALUES ('105', '1003', '123965656');

